# Changelog


## [1.2.0] - 2025-03-31
1. 移植自tyme4j。

## [1.3.0] - 2025-04-16
1. 新增：干支年、干支月、干支日、干支时辰。
2. 新增：童限的所属大运、开始年龄、结束年龄。
3. 废弃：八字的建除十二值神（建议从干支日中获取）。
4. 废弃：农历日的当天年干支、当天月干支（建议从干支日中获取）。
5. 废弃：农历时辰的当时年干支、当时月干支、当时日干支（建议从干支时辰中获取）。
6. 废弃：童限的结束农历年（建议取结束干支年）。
7. 废弃：大运的开始农历年、结束农历年（建议取开始干支年、结束干支年）。
8. 废弃：小运的农历年（建议取干支年）。
9. 修复：八字身宫计算错误的问题。

## [1.3.2] - 2025-04-24
1. 修复：之前版本打包错误。

## [1.3.3] - 2025-06-10
1. 新增：藏历。
2. 优化：宜忌。
3. 修复：候的错别字。

## [1.3.4] - 2025-06-30
1. 新增：候可精确到公历时刻。
2. 修改：2018之后的△T参数。

## [1.3.5] - 2025-09-09
1. 修复：极端情况下八字转公历时刻出现遗漏的问题。
2. 优化：代码。

## [1.3.6] - 2025-09-11
1. #4 合并代码。

## [1.3.7] - 2025-09-27
1. 新增：公历日、公历时刻、农历日获取月相。
2. 新增：月相获取公历日、公历时刻。
3. 优化：更新△T参数。
4. 修复：农历闰月干支错误(应随上月)。

## [1.3.8] - 2025-09-30
1. 修复：闰月月相错误。

## [1.3.9] - 2025-10-31
1. 新增：三柱 ThreePillars。
2. 新增：农历日、干支日获取三柱。
3. 新增：三柱反推公历日。
4. 新增：节气直接获取公历日(用于日历)。
5. 优化：干支日获取干支月与寿星万年历一致。
6. 优化：公历日获取节气(用于日历，与寿星万年历一致)。

## [1.4.0] - 2025-11-05
1. 新增：2026年法定假日。

## [1.4.1] - 2026-01-11
1. 修复：某些情况下月干支的错误。
2. 移除：农历月的缓存数据。
3. 优化：减少对象引用。

## [1.4.2] - 2026-01-13
1. 修复：导出unit包。

## [1.4.3] - 2026-01-19
1. 升级：python版本升级到3.10。
2. 修复：某些公历日获取节气错误。
3. 修复：某些公历日转干支日错误。

## [1.4.4] - 2026-02-09
1. 修复：2026-09-20的调休问题。
2. 优化：农历传统节日的性能。
3. 优化：打包。

## [1.4.5] - 2026-03-09
1. 修复：农历日is_before/is_after比较的错误。
2. 重构：藏历。
3. 新增：事件。
4. 优化：代码和算法。
